@@ -1,23 +1,14 @@
 import datetime as dt
 import re
-from collections import namedtuple
-from pathlib import Path
 
 import pytest
 
-import ravenpy
-from ravenpy.config.commands import (
-    BasinStateVariablesCommand,
-    EvaluationPeriod,
-    GriddedForcingCommand,
-    HRUStateVariableTableCommand,
-)
+from ravenpy.config.commands import EvaluationPeriod, GriddedForcingCommand
 from ravenpy.config.rvs import OST, RVC, RVH, RVI, RVP, RVT, Config
 from ravenpy.extractors import (
     RoutingProductGridWeightExtractor,
     RoutingProductShapefileExtractor,
 )
-from ravenpy.utilities.testdata import get_local_testdata
 
 
 class TestRV:
@@ -78,7 +69,7 @@ class TestRVI:
     def test_supress_output(self):
         rvi = RVI(None)
         rvi.suppress_output = True
-        assert rvi.suppress_output == ":SuppressOutput\n:DontWriteWatershedStorage"
+        assert rvi.suppress_output == ":SuppressOutput\n:DontWriteWatershedStorage\n"
 
         rvi = RVI(None)
         rvi.suppress_output = False
@@ -86,15 +77,15 @@ class TestRVI:
 
 
 class TestRVC:
-    @classmethod
-    def setup_class(self):
-        sol = open(get_local_testdata("gr4j_cemaneige/solution.rvc")).read()
+    @pytest.fixture(autouse=True)
+    def setup(self, get_file):
+        sol = open(get_file("gr4j_cemaneige/solution.rvc")).read()
         self.rvc = RVC.create_solution(sol)
 
     def test_parse(self):
         assert len(self.rvc.hru_states) == 1
-        assert self.rvc.hru_states[1].atmosphere == 821.98274
-        assert self.rvc.hru_states[1].atmos_precip == -1233.16
+        assert self.rvc.hru_states[1].data["ATMOSPHERE"] == 821.98274
+        assert self.rvc.hru_states[1].data["ATMOS_PRECIP"] == -1233.16
 
         assert len(self.rvc.basin_states) == 1
         assert self.rvc.basin_states[1].channel_storage == 0
@@ -106,9 +97,9 @@ class TestRVC:
 
 
 class TestRVH:
-    @classmethod
-    def setup_class(self):
-        shp = get_local_testdata("raven-routing-sample/finalcat_hru_info.zip")
+    @pytest.fixture(autouse=True)
+    def setup(self, get_file):
+        shp = get_file("raven-routing-sample/finalcat_hru_info.zip")
         extractor = RoutingProductShapefileExtractor(shp)
         config = extractor.extract()
         self.rvh = RVH(None)
@@ -148,9 +139,9 @@ class TestRVH:
 
 
 class TestRVP:
-    @classmethod
-    def setup_class(self):
-        shp = get_local_testdata("raven-routing-sample/finalcat_hru_info.zip")
+    @pytest.fixture(autouse=True)
+    def setup(self, get_file):
+        shp = get_file("raven-routing-sample/finalcat_hru_info.zip")
         extractor = RoutingProductShapefileExtractor(shp)
         config = extractor.extract()
         self.rvp = RVP(None)
@@ -168,10 +159,10 @@ class TestRVP:
 
 
 class TestRVT:
-    @classmethod
-    def setup_class(self):
-        input_file = get_local_testdata("raven-routing-sample/VIC_streaminputs.nc")
-        routing_file = get_local_testdata("raven-routing-sample/finalcat_hru_info.zip")
+    @pytest.fixture(autouse=True)
+    def setup(self, get_file):
+        input_file = get_file("raven-routing-sample/VIC_streaminputs.nc")
+        routing_file = get_file("raven-routing-sample/finalcat_hru_info.zip")
         extractor = RoutingProductGridWeightExtractor(input_file, routing_file)
         gws = extractor.extract()
         self.gfc = GriddedForcingCommand(grid_weights=gws)
@@ -184,10 +175,10 @@ class TestRVT:
         # FIXME: This test is not superb.
         assert len(res.split("\n")) == 224
 
-    def test_gauges(self):
+    def test_gauges(self, get_file):
         rvt = RVT(config=None)
-        rvt.nc_index = [0, 1, 2]
-        rvt.configure_from_nc_data([get_local_testdata("famine/famine_input.nc")])
+        rvt.meteo_idx = [0, 1, 2]
+        rvt.configure_from_nc_data([get_file("famine/famine_input.nc")])
         out = rvt.to_rv()
         assert len(re.findall(":Gauge", out)) == 3
         assert set(re.findall(r":StationIdx\s*(\d)", out)) == {"1", "2", "3"}
